@@ -51,10 +51,13 @@ class Person(models.Model):
         lambda field, request, instance: settings.PREFERRED_LANGUAGES
     )
 
-    categories = models.ManyToManyField(
-        Term, blank=True, limit_choices_to={"category__slug": "category"}
+    tags = models.ManyToManyField(
+        Term,
+        blank=True,
+        limit_choices_to={"vocabulary__slug": "tag"},
+        # db_table="core_person_categories",
     )
-    categories.verbose_name = _("Categories")
+    tags.verbose_name = _("Tags")
 
     primary_postal_address = models.ForeignKey(
         "core.Postal",
@@ -100,7 +103,7 @@ class Person(models.Model):
     _type = models.ForeignKey(
         Term, on_delete=models.SET_NULL, null=True, blank=True, related_name="+"
     )
-    _type.verbose_name = _("Category")
+    _type.verbose_name = _("Person Category")
 
     objects = PersonManager()
 
@@ -192,12 +195,15 @@ class NaturalPerson(Person):
     first_name = models.CharField(_("First Name"), max_length=255, blank=True)
     middle_name = models.CharField(_("Middle Name"), max_length=255, blank=True)
     last_name = models.CharField(_("Last Name"), max_length=255, blank=True)
+    autogenerate_displayname = models.BooleanField(
+        _("Autogenerate Display Name"), default=True
+    )
     title = models.ForeignKey(
         Term,
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "title"},
+        limit_choices_to={"vocabulary__slug": "title"},
         related_name="title_persons",
     )
     title.verbose_name = _("Title")
@@ -206,7 +212,7 @@ class NaturalPerson(Person):
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "salutation"},
+        limit_choices_to={"vocabulary__slug": "salutation"},
         related_name="+",
     )
     salutation.verbose_name = _("Salutation")
@@ -216,7 +222,7 @@ class NaturalPerson(Person):
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "form_of_address"},
+        limit_choices_to={"vocabulary__slug": "form_of_address"},
         related_name="+",
     )
     form_of_address.verbose_name = _("Form of address")
@@ -234,7 +240,7 @@ class NaturalPerson(Person):
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "gender"},
+        limit_choices_to={"vocabulary__slug": "gender"},
         related_name="gender_persons",
     )
     gender.verbose_name = _("Gender")
@@ -244,9 +250,9 @@ class NaturalPerson(Person):
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "naturaltype"},
+        limit_choices_to={"vocabulary__slug": "naturaltype"},
     )
-    type.verbose_name = _("Person category")
+    type.verbose_name = _("Person Type")
 
     def age(self):
         if not self.date_of_birth:
@@ -262,7 +268,7 @@ class NaturalPerson(Person):
     age.verbose_name = _("Age")
 
     def save(self, *args, **kwargs):
-        if not self.name:
+        if self.autogenerate_displayname:
             self.name = self.first_name + " " + self.last_name
         if self.decease_date:
             self.deceased = True
@@ -283,7 +289,7 @@ class LegalPerson(Person):
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "legaltype"},
+        limit_choices_to={"vocabulary__slug": "legaltype"},
     )
     type.verbose_name = _("Type")
 
@@ -298,16 +304,13 @@ class LegalPerson(Person):
         verbose_name_plural = _("Legal Persons")
 
 
-LegalPerson._meta.get_field("name").verbose_name = _("Name")
-
-
 class PersonAssociation(Person):
     type = models.ForeignKey(
         Term,
         on_delete=models.SET_NULL,
         null=True,
         blank=True,
-        limit_choices_to={"category__slug": "associationtype"},
+        limit_choices_to={"vocabulary__slug": "associationtype"},
     )
     type.verbose_name = _("Type")
 
